#!/bin/bash
# synteny processing steps
# by WRF 2020-01-31

###
# NOTE:
# in R scripts, all filenames are HARDCODED
# so these would need to be changed to re-run and regenerate the figures

# Synteny analysis summary:
# Synteny plots, also called dot plots, were generated using a combination of custom Python and R scripts to generate plots of unidirectional BLAST hits showing the position on the respective scaffold. AUGUSTUS gene models from E. muelleri were used.

# For each pair of genomes, proteins from the query species (typically Ephydatia) were searched against proteins of the target genome using blastp, with an e-value cutoff of 0.001. The scaffolds of each genome, the position of protein-coding genes on the scaffolds, and the tabular blast results were all used as inputs for the Python script (scaffold_synteny.py), which compiled a table of matches by the relative gene position on each genome.

# This table was used as input for the R script (draw_2d_synteny.R) to create the dot plots. Proteins were excluded from either genome if they had greater than 20 matches (i.e. large protein families or transposons), as these would likely cause random observations of synteny.

# General use Python and R scripts:
# scaffold_synteny.py
# draw_2d_synteny.R
#
# are found at:
# https://github.com/wrf/genomeGTFtools
# for the version used in this genome project, use:
# https://github.com/wrf/genomeGTFtools/releases/tag/Emu-v1

# Synteny results are based on the gene positions on the scaffolds and the results of the blast between the two species, and are found in the two _raw_data folders. These results are deterministic, and should be reproduced exactly following the instructions below.
# Each analysis also contains a randomized version. These are random (and hence are not deterministic) but can be useful for comparison.

# g-random : globally randomized gene positions across the entire genome
# s-random : genes randomized within each scaffold for only the query genome
# ds-random : randomized within each scaffold, for positions of the query and subject genomes


# Subfolder contents:

#emu_vs_animals_raw_data:
#augustus_sysnames_prots_vs_Brafl2-AUG_random_scaffold2D_test.tab
#augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab
#augustus_sysnames_prots_vs_Nve2_scaffold2D_random.tab
#augustus_sysnames_prots_vs_Nve2_scaffold2D.tab
#augustus_sysnames_prots_vs_Triad1_scaffold2D_random.tab
#augustus_sysnames_prots_vs_Triad1_scaffold2D.tab

#emu_vs_animals_supp_figs:
#augustus_sysnames_prots_vs_Brafl2-AUG_random_scaffold2D_test.pdf
#augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.pdf
#augustus_sysnames_prots_vs_Nve2_scaffold2D.pdf
#augustus_sysnames_prots_vs_Nve2_scaffold2D_random.pdf
#augustus_sysnames_prots_vs_Triad1_scaffold2D.pdf
#augustus_sysnames_prots_vs_Triad1_scaffold2D_random.pdf

#emu_vs_choanos_raw_data:
#augustus_sysnames_prots_vs_Monosiga_scaffold2D_random.tab
#augustus_sysnames_prots_vs_Monosiga_scaffold2D.tab
#augustus_sysnames_prots_vs_Srosetta_scaffold2D_random.tab
#augustus_sysnames_prots_vs_Srosetta_scaffold2D.tab
#monbr1_vs_srosetta_scaffold2d_points_randomized.tab
#monbr1_vs_srosetta_scaffold2d_points.tab

#emu_vs_choanos_supp_figs:
#augustus_sysnames_prots_vs_Monosiga_scaffold2D.pdf
#augustus_sysnames_prots_vs_Monosiga_scaffold2D_random.pdf
#augustus_sysnames_prots_vs_Srosetta_scaffold2D.pdf
#augustus_sysnames_prots_vs_Srosetta_scaffold2D_random.pdf
#monbr1_vs_srosetta_scaffold2d_points.pdf
#monbr1_vs_srosetta_scaffold2d_points_randomized.pdf

#figures: final versions used for the paper
#ephydatia_Bf_synteny_dot_plots_w_chr22.pdf
#ephydatia_combined_synteny_dot_plots.pdf
#ephydatia_Ta_synteny_dot_plots_w_chr22.pdf

#fishers_test_graphs: plots of the pvalues, corresponding to the scaffolds in the supplementary figures, made by script synteny_improbability_calcs.R
#choanoflagellates_ftest_pvalue_squares.pdf
#ephydatia_vs_animals_ftest_pvalue_squares.pdf
#hoilungia_vs_trichoplax_ftest_pvalue_squares.pdf

#fishers_test_pvalue_csv: pvalues calculated for the above plots, made by script synteny_improbability_calcs.R
#ephydatia_vs_branchiostoma_ftest_pvalue.csv
#ephydatia_vs_branchiostoma_ftest_pvalue_g-random.csv
#ephydatia_vs_monosiga_ftest_pvalue.csv
#ephydatia_vs_monosiga_ftest_pvalue_g-random.csv
#ephydatia_vs_nematostella_ftest_pvalue.csv
#ephydatia_vs_nematostella_ftest_pvalue_g-random.csv
#ephydatia_vs_salpingoeca_ftest_pvalue.csv
#ephydatia_vs_salpingoeca_ftest_pvalue_g-random.csv
#ephydatia_vs_trichoplax_ftest_pvalue.csv
#ephydatia_vs_trichoplax_ftest_pvalue_g-random.csv
#monosiga_vs_salpingoeca_ftest_pvalue.csv
#monosiga_vs_salpingoeca_ftest_pvalue_g-random.csv

#microsynteny_gff: tracks for genome browsers
#augustus_sysnames_prots_vs_Brafl2_microsynteny.gff
#augustus_sysnames_prots_vs_Nve2_microsynteny.gff
#augustus_sysnames_prots_vs_Triad1_microsynteny.gff

#placozoan_comparison:
#hoilungia_vs_trichoplax_ftest_pvalue.csv
#hoilungia_vs_trichoplax_ftest_pvalue_ds-random.csv
#hoilungia_vs_trichoplax_ftest_pvalue_g-random.csv
#hoilungia_vs_trichoplax_scaffold2d_points_ds-random.pdf
#hoilungia_vs_trichoplax_scaffold2d_points_ds-random.tab
#hoilungia_vs_trichoplax_scaffold2d_points_g-random.pdf
#hoilungia_vs_trichoplax_scaffold2d_points_g-random.tab
#hoilungia_vs_trichoplax_scaffold2d_points.pdf
#hoilungia_vs_trichoplax_scaffold2d_points_s-random.pdf
#hoilungia_vs_trichoplax_scaffold2d_points_s-random.tab
#hoilungia_vs_trichoplax_scaffold2d_points.tab

#scripts: associated scripts for the analysis
#emu_synteny_processing_steps.sh
#ephydatia_combined_synteny_dot_plots.R
#synteny_improbability_calcs.R



########################
# vs Salpingoeca genomic

blastp -query augustus_sysnames_prots.fasta -db ~/genomes/salpingoeca_rosetta/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.pep.all.fa -outfmt 6 -evalue 1e-3 -num_threads 6 -max_target_seqs 100 > augustus_sysnames_prots_vs_Srosetta_blastp.tab

~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Srosetta_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/salpingoeca_rosetta/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.dna.toplevel.fa.gz -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/salpingoeca_rosetta/srosetta_mrna_only_ID_renamed.gff -l 300 -L 50 -G 20 > augustus_sysnames_prots_vs_Srosetta_scaffold2D.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Srosetta_scaffold2D.tab Salpingoeca-rosetta Ephydatia-muelleri

# randomized
~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Srosetta_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/salpingoeca_rosetta/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.dna.toplevel.fa.gz -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/salpingoeca_rosetta/srosetta_mrna_only_ID_renamed.gff -l 300 -L 50 -G 20 -R > augustus_sysnames_prots_vs_Srosetta_scaffold2D_random.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Srosetta_scaffold2D_random.tab Salpingoeca-rosetta Ephydatia-muelleri



###################################
# vs Monosiga AUGUSTUS reannotation
# reannotations are here:
# https://bitbucket.org/wrf/genome-reannotations/downloads/

blastp -query augustus_sysnames_prots.fasta -db ~/genomes/monosiga_brevicollis/Monbr1_augustus_v1.prot_no_rename.fasta -outfmt 6 -evalue 1e-3 -max_target_seqs 100 -num_threads 6 > augustus_sysnames_prots_vs_Monbr1-AUG_blastp.tab

~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Monbr1-AUG_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/monosiga_brevicollis/Monbr1_scaffolds.fasta -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/monosiga_brevicollis/Monbr1_augustus_v1_no_comment.gff -l 300 -L 40 > augustus_sysnames_prots_vs_Monosiga_scaffold2D.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Monosiga_scaffold2D.tab Monosiga-brevicollis Ephydatia-muelleri

# monosiga randomized
~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Monbr1-AUG_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/monosiga_brevicollis/Monbr1_scaffolds.fasta -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/monosiga_brevicollis/Monbr1_augustus_v1_no_comment.gff -l 300 -L 40 -G 20 -R > augustus_sysnames_prots_vs_Monosiga_scaffold2D_random.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Monosiga_scaffold2D_random.tab Monosiga-brevicollis Ephydatia-muelleri

# monbr1 vs salpingoeca
~/git/genomeGTFtools/scaffold_synteny.py -b ~/genomes/monosiga_brevicollis/monbr1_augustus_vs_srosetta_blastp.tab -q ~/genomes/monosiga_brevicollis/Monbr1_augustus_v1_no_comment.gff -d ~/genomes/salpingoeca_rosetta/srosetta_mrna_only_ID_renamed.gff -f ~/genomes/monosiga_brevicollis/Monbr1_scaffolds.fasta -F ~/genomes/salpingoeca_rosetta/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.dna.toplevel.fa.gz -l 40 -L 50 -G 20 > monbr1_vs_srosetta_scaffold2d_points.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R monbr1_vs_srosetta_scaffold2d_points.tab Monosiga-brevicollis Salpingoeca-rosetta

~/git/genomeGTFtools/scaffold_synteny.py -b ~/genomes/monosiga_brevicollis/monbr1_augustus_vs_srosetta_blastp.tab -q ~/genomes/monosiga_brevicollis/Monbr1_augustus_v1_no_comment.gff -d ~/genomes/salpingoeca_rosetta/srosetta_mrna_only_ID_renamed.gff -f ~/genomes/monosiga_brevicollis/Monbr1_scaffolds.fasta -F ~/genomes/salpingoeca_rosetta/Salpingoeca_rosetta.Proterospongia_sp_ATCC50818.dna.toplevel.fa.gz -l 40 -L 50 -G 20 -R > monbr1_vs_srosetta_scaffold2d_points_randomized.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R monbr1_vs_srosetta_scaffold2d_points_randomized.tab Monosiga-brevicollis Salpingoeca-rosetta


#####################################
# vs Trichoplax AUGUSTUS reannotation
# reannotations are here:
# https://bitbucket.org/wrf/genome-reannotations/downloads/

blastp -query augustus_sysnames_prots.fasta -db ~/genomes/trichoplax_adhaerens/Trichoplax_scaffolds_JGI_AUGUSTUS_maxtrack2.prots.fasta -outfmt 6 -evalue 1e-3 -max_target_seqs 100 -num_threads 6 > augustus_sysnames_prots_vs_Triad1-AUG_blastp.tab

sed s/Trichoplax_adhaerens_//g augustus_sysnames_prots_vs_Triad1-AUG_blastp.tab > augustus_sysnames_prots_vs_Triad1-AUG_no_rename_blastp.tab

~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Triad1-AUG_no_rename_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/trichoplax_adhaerens/Triad1_genomic_scaffolds.fasta -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d Trichoplax_scaffolds_JGI_AUGUSTUS_transcript_only.gff --blast-db-delimiter __ -l 300 -L 100 -G 20 > augustus_sysnames_prots_vs_Triad1_scaffold2D.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Triad1_scaffold2D.tab Trichoplax-adhaerens Ephydatia-muelleri

# trichoplax randomized
~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Triad1-AUG_no_rename_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/trichoplax_adhaerens/Triad1_genomic_scaffolds.fasta -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/trichoplax_adhaerens/Trichoplax_scaffolds_JGI_AUGUSTUS_transcript_only.gff --blast-db-delimiter __ -l 300 -L 100 -G 20 -R > augustus_sysnames_prots_vs_Triad1_scaffold2D_random.tab

# genome browser track
~/git/genomeGTFtools/microsynteny.py -q ../augustus/hints_utr_pred/augustus_vs_nb_sysnames.gff -d Trichoplax_scaffolds_JGI_AUGUSTUS_transcript_only.gff.gz -b augustus_sysnames_prots_vs_Triad1-AUG_no_rename_blastp.tab.gz --blast-db-delimiter __ -G > augustus_sysnames_prots_vs_Triad1_microsynteny.gff

ln -s ~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Triad1_microsynteny.gff augustus_sysnames_prots_vs_Triad1_microsynteny.gff

/var/www/html/jbrowse/bin/flatfile-to-json.pl --out ./ --gff augustus_sysnames_prots_vs_Triad1_microsynteny.gff --trackType CanvasFeatures --trackLabel Triad-microsynteny



###################################
# vs Nematostella v2 Vienna dataset
# https://figshare.com/articles/Nematostella_vectensis_transcriptome_and_gene_models_v2_0/807696

blastp -query augustus_sysnames_prots.fasta -db ~/est/cnidarians/nematostella_vienna_protein.fasta -outfmt 6 -evalue 1e-3 -max_target_seqs 100 -num_threads 6 > augustus_sysnames_prots_vs_Nve2_blastp.tab

fix_nematostella_gtf.py nveGenes.vienna130208.nemVec1.gtf > nveGenes.vienna130208.nemVec1.gff
# script at:
# https://bitbucket.org/wrf/genome-reannotations/src/master/jbrowse-tracks/nematostella/

~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Nve2_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/nematostella_vectensis/Nemve1.fasta.gz -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/nematostella_vectensis/nveGenes.vienna130208.nemVec1.gff -l 300 -L 100 -G 20 > augustus_sysnames_prots_vs_Nve2_scaffold2D.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Nve2_scaffold2D.tab Nematostella-vectensis Ephydatia-muelleri

# randomized
~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Nve2_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/nematostella_vectensis/Nemve1.fasta.gz -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/nematostella_vectensis/nveGenes.vienna130208.nemVec1.gff -l 300 -L 100 -G 20 -R > augustus_sysnames_prots_vs_Nve2_scaffold2D_random.tab

# genome browser track
~/git/genomeGTFtools/microsynteny.py -q ../augustus/hints_utr_pred/augustus_vs_nb_sysnames.gff -d nveGenes.vienna130208.nemVec1.gff.gz -b augustus_sysnames_prots_vs_Nve2_blastp.tab.gz -G > augustus_sysnames_prots_vs_Nve2_microsynteny.gff

ln -s ~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Nve2_microsynteny.gff augustus_sysnames_prots_vs_Nve2_microsynteny.gff

/var/www/html/jbrowse/bin/flatfile-to-json.pl --out ./ --gff augustus_sysnames_prots_vs_Nve2_microsynteny.gff --trackType CanvasFeatures --trackLabel Nematostella-microsynteny



#########################################
# vs Branchiostoma AUGUSTUS reannotations
# reannotations are here:
# https://bitbucket.org/wrf/genome-reannotations/downloads/

~/diamond-linux64/diamond makedb --in Brafl2_augustus.prot.no_rename.fasta -d Brafl2_augustus.prot.no_rename.fasta

~/diamond-linux64/diamond blastp -d ~/genomes/branchiostoma_floridae/Brafl2_augustus.prot.no_rename.fasta -q augustus_sysnames_prots.fasta -o augustus_sysnames_prots_vs_Brafl2-AUG_blastp.tab

~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Brafl2-AUG_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/branchiostoma_floridae/Branchiostoma_floridae_v2.0.assembly.fasta.gz -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/branchiostoma_floridae/Brafl2_augustus.nocomment.gff --blast-db-delimiter __ -l 300 -L 200 -G 20 > augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab Branchiostoma-floridae Ephydatia-muelleri


# randomized
 ~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Brafl2-AUG_blastp.tab.gz -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/branchiostoma_floridae/Branchiostoma_floridae_v2.0.assembly.fasta.gz -q ../augustus/augustus_vs_nb_sysnames.gff.gz -d ~/genomes/branchiostoma_floridae/Brafl2_augustus.nocomment.gff --blast-db-delimiter __ -l 300 -L 200 -R -G 20 > augustus_sysnames_prots_vs_Brafl2-AUG_random_scaffold2D_test.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Brafl2-AUG_random_scaffold2D_test.tab Branchiostoma-floridae Ephydatia-muelleri


# genome browser track
~/git/genomeGTFtools/microsynteny.py -q ../augustus/hints_utr_pred/augustus_vs_nb_sysnames.gff -d Brafl2_augustus.nocomment.gff.gz -b augustus_sysnames_prots_vs_Brafl2-AUG_blastp.tab.gz --blast-db-delimiter __ -G > augustus_sysnames_prots_vs_Brafl2_microsynteny.gff

ln -s ~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2_microsynteny.gff augustus_sysnames_prots_vs_Brafl2_microsynteny.gff

/var/www/html/jbrowse/bin/flatfile-to-json.pl --out ./ --gff augustus_sysnames_prots_vs_Brafl2_microsynteny.gff --trackType CanvasFeatures --trackLabel Branchiostoma-microsynteny


####################
# vs Amphimedon v2.1
blastp -query augustus_sysnames_prots.fasta -db ~/est/porifera/Amphimedon_proteins_v2-1.fasta -outfmt 6 -evalue 1e-2 -max_target_seqs 100 -num_threads 4 > augustus_sysnames_prots_vs_Aqu2_blastp.tab

~/git/genomeGTFtools/microsynteny.py -b augustus_sysnames_prots_vs_Aqu2_blastp.tab -q ../augustus/augustus_vs_nb_sysnames.gff -d ~/genomes/amphimedon_queenslandica/Aqu2.1_Genes.gff3 -D "|" --blast-db-delimiter "|" -G > augustus_sysnames_prots_vs_Aqu2_blastp.gff

##########
# vs Sycon
blastp -query augustus_sysnames_prots.fasta -db ~/genomes/sycon_ciliatum/sycon.cds.trans.fa -outfmt 6 -evalue 1e-2 -max_target_seqs 100 -num_threads 6 > augustus_sysnames_prots_vs_Scil_blastp.tab

~/git/genomeGTFtools/scaffold_synteny.py -b augustus_sysnames_prots_vs_Scil_blastp.tab -f ../ASM_HIC_394/renumbered_final_nb.fa -F ~/genomes/sycon_ciliatum/sycon.genome.fa -q ../augustus/augustus_vs_nb_sysnames.gff -d ~/genomes/sycon_ciliatum/sycon.cds.gff3 -D '.' -l 300 -L 100 > augustus_sysnames_prots_vs_Scil_scaffold2D.tab

Rscript ~/git/genomeGTFtools/synteny_2d_plot.R augustus_sysnames_prots_vs_Scil_scaffold2D.tab Sycon-ciliatum Ephydatia-muelleri


