# calculation of probabilities of matching genes between scaffolds, as having derived from a random distribution
# by WRF 2019-10-15

##
##
###################
## general notes ##
###################
# script has 15 input files, which are:

# hoilungia_vs_trichoplax_scaffold2d_points.tab
# hoilungia_vs_trichoplax_scaffold2d_points_g-random.tab
# hoilungia_vs_trichoplax_scaffold2d_points_ds-random.tab
# monbr1_vs_srosetta_scaffold2d_points.tab
# monbr1_vs_srosetta_scaffold2d_points_randomized.tab
# augustus_sysnames_prots_vs_Monosiga_scaffold2D.tab
# augustus_sysnames_prots_vs_Monosiga_scaffold2D_random.tab
# augustus_sysnames_prots_vs_Srosetta_scaffold2D.tab
# augustus_sysnames_prots_vs_Srosetta_scaffold2D_random.tab
# augustus_sysnames_prots_vs_Triad1_scaffold2D.tab
# augustus_sysnames_prots_vs_Triad1_scaffold2D_random.tab
# augustus_sysnames_prots_vs_Nve2_scaffold2D.tab
# augustus_sysnames_prots_vs_Nve2_scaffold2D_random.tab
# augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab
# augustus_sysnames_prots_vs_Brafl2-AUG_random_scaffold2D_test.tab

# script then produces 3 graphs of heatmaps of significance
# and 15 csv files of the raw p-values from Fisher's exact test

# analysis is modeled from this explanation from Srivastava 2008
# "Scaffold_8 has genes belonging to 174 of the 5,487 ancestral gene clusters, while human chromosome segment 10.4
# has genes belonging to 165 of them. 54 ancestral gene clusters have genes from both Scaffold_8 and human 
# chromosome segment 10.4. Fisher's exact test rejects the null model that the gene complements of Trichoplax 
# scaffold_8 and human chromosome segment 10.4 are drawn independently from the set of ancestral genes, and 
# that all ancestral genes have an equal probability of having a descendant on a given segment"

#s2008_matrix = matrix(data=c(54, 174, 165, 5487), nrow=2)
#s2008_ft = fisher.test(test_matrix)
#s2008_ft$p.value
# [1] 4.75784e-30

# define function to calculate p values for each scaffold pair across both genomes
calculate_ftest_pvalues <- function(freq_matrix) {
	# start from empty vector
	p_values = c()
	nscaf_g1 = dim(freq_matrix)[1]
	nscaf_g2 = dim(freq_matrix)[2]
	match_total = sum(freq_matrix)
	# loop over each matrix position, calculate Fishers test
	for ( i in 1:nscaf_g1) {
		for (j in 1:nscaf_g2) {
			h1h1 = freq_matrix[i,j]
			h1h0 = sum(freq_matrix[i])
			h0h1 = sum(freq_matrix[j])
			h0h0 = match_total - h1h0 - h0h1 + h1h1
			test_matrix = matrix( data=c(h1h1,h1h0,h0h1,h0h0), nrow=2)
			ft = fisher.test(test_matrix)
			p_values = c(p_values, ft$p.value)
		}
	}
	return(p_values)
}



##
## Hoilungia vs Trichoplax
##

# read in all data, sort out scaffold data from points
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/placozoa/hoilungia_vs_trichoplax_scaffold2d_points.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
scafdata1
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.003)
is_longscafs1
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.005)
is_longscafs2
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]

# compile data frame of just scaffold matches from the points
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])

# generate 2d table of frequencies
HhTa_match_freq_table = table(scaffold_data)

scaf1_names = scafdata1[,2]
# reorder scaffold names to match size
sc1_reorder_index = match(scaf1_names,row.names(HhTa_match_freq_table))[is_longscafs1]
sc1_reorder_index
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(HhTa_match_freq_table))[is_longscafs2]
sc2_reorder_index
Ta_scaf_names = gsub("(contig_\\d+)_length.*", "\\1", row.names(HhTa_match_freq_table)[sc1_reorder_index], perl=TRUE)
Hh_scaf_names = colnames(HhTa_match_freq_table)[sc2_reorder_index]
Hh_scaf_names

# reorder matrix to match dot plot order
reordered_table = HhTa_match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2

# calculate p values using the match frequencies
HhTa_p_values = calculate_ftest_pvalues(match_freq_matrix)

# convert to lower bound, correct for multiple tests
p_value_adj = HhTa_p_values * ntests
range(HhTa_p_values)
p_value_log = floor(-log10(p_value_adj))
hist(p_value_log, breaks=20, ylim=c(0,500))
sum(as.integer(p_value_log > 65))
p_value_log[p_value_log<1] = 1
p_value_log[p_value_log>100] = 100
range(p_value_log)
# create final matrix for input into image()
HhTa_p_value_mat = matrix( data=p_value_log, nrow=nscaf_g1, byrow=TRUE )
# write csv of raw pvalue matrix
raw_p_value_mat = matrix( data=HhTa_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Hh_scaf_names
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/placozoa/hoilungia_vs_trichoplax_ftest_pvalue.csv", row.names=Ta_scaf_names )

all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/placozoa/hoilungia_vs_trichoplax_scaffold2d_points_g-random.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.003)
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.005)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
HhTa_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
HhTa_g_random_p_value_adj = HhTa_g_random_p_values * ntests
range(HhTa_g_random_p_values)
HhTa_g_random_p_value_log = floor(-log10(HhTa_g_random_p_value_adj))
hist(HhTa_g_random_p_value_log, breaks=20, ylim=c(0,500))
sum(as.integer(HhTa_g_random_p_value_log > 65))
HhTa_g_random_p_value_log[HhTa_g_random_p_value_log<1] = 1
HhTa_g_random_p_value_log[HhTa_g_random_p_value_log>100] = 100
range(HhTa_g_random_p_value_log)
# final matrix
HhTa_g_random_p_value_mat = matrix( data=HhTa_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE )
# write csv
raw_p_value_mat = matrix( data=HhTa_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Hh_scaf_names
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/placozoa/hoilungia_vs_trichoplax_ftest_pvalue_g-random.csv", row.names=Ta_scaf_names )
# Nb with lower value than the global min of the randomized set
HhTa_p_values[HhTa_p_values<(min(HhTa_g_random_p_values)/ntests)]
# NBcS, Bonferroni corrected scaffolds, each relative to the randomized
HhTa_p_values[(HhTa_p_values / HhTa_g_random_p_values) < (0.01/ntests)]


all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/placozoa/hoilungia_vs_trichoplax_scaffold2d_points_ds-random.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.003)
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.005)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
HhTa_ds_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
HhTa_ds_random_p_value_adj = HhTa_ds_random_p_values * ntests
range(HhTa_ds_random_p_values)
HhTa_ds_random_p_value_log = floor(-log10(HhTa_ds_random_p_value_adj))
hist(HhTa_ds_random_p_value_log, breaks=20, ylim=c(0,500))
sum(as.integer(HhTa_ds_random_p_value_log > 65))
HhTa_ds_random_p_value_log[HhTa_ds_random_p_value_log<1] = 1
HhTa_ds_random_p_value_log[HhTa_ds_random_p_value_log>100] = 100
range(HhTa_ds_random_p_value_log)
# final matrix
HhTa_ds_random_p_value_mat = matrix( data=HhTa_ds_random_p_value_log, nrow=nscaf_g1, byrow=TRUE )
# write csv
raw_p_value_mat = matrix( data=HhTa_ds_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Hh_scaf_names
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/placozoa/hoilungia_vs_trichoplax_ftest_pvalue_ds-random.csv", row.names=Ta_scaf_names )


colorscheme = colorRampPalette(c("#f1eef6","#66a4c2","#4d004b"))(100)
#colorscheme = colorRampPalette(c("#f7fcfd","#66c2a4","#b2abd2"))(99)
plot(1:100,1:100,cex=3,pch=18,col=colorscheme)
pdf(file="~/genomes/ephydatia_muelleri/synteny/hoilungia_vs_trichoplax_ftest_pvalue_squares.pdf", paper="a4", width=8, height=11)
layout(mat=matrix(c(1,1,2,2,3,3), nrow=3, byrow=TRUE),widths=c(1,1,1))
par(mar=c(4,6,3,1))
image(z=HhTa_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Fisher's exact test P values\nT.adhaerens vs H.hongkongensis")
mtext( Ta_scaf_names, side=1, at=seq(0,1,1/(length(Ta_scaf_names)-1)), las=2, cex=0.35)
mtext( Hh_scaf_names,side=2,at=seq(0,1,1/(length(Hh_scaf_names)-1)), las=1, cex=0.75)
mtext( "A", side=3, at=c(-0.1), line=1, cex=2)
image(z=HhTa_g_random_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Globally randomized Fisher's exact test P values\n T.adhaerens vs H.hongkongensis")
mtext( Ta_scaf_names, side=1, at=seq(0,1,1/(length(Ta_scaf_names)-1)), las=2, cex=0.35)
mtext( Hh_scaf_names,side=2,at=seq(0,1,1/(length(Hh_scaf_names)-1)), las=1, cex=0.75)
rect(seq(0.500, 0.896, 0.004),rep(0.8,length(colorscheme)), seq(0.504, 0.9, 0.004) ,rep(0.9,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.5,0.75, "p=0.1", cex=2)
text(0.9,0.75, "p<1e-100" , cex=2)
mtext( "B", side=3, at=c(-0.1), line=1, cex=2)
image(z=HhTa_ds_random_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Scaffold randomized Fisher's exact test P values\n T.adhaerens vs H.hongkongensis")
mtext( Ta_scaf_names, side=1, at=seq(0,1,1/(length(Ta_scaf_names)-1)), las=2, cex=0.35)
mtext( Hh_scaf_names,side=2,at=seq(0,1,1/(length(Hh_scaf_names)-1)), las=1, cex=0.75)
mtext( "C", side=3, at=c(-0.1), line=1, cex=2)
dev.off()





##
##
##
##
##
##
## Monosiga vs Salpingoeca
##
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/choanoflagellates/monbr1_vs_srosetta_scaffold2d_points.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
scafdata1
longestscaf1 = max(scafdata1[,6])
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1
longscafs1 = c(0, scafdata1[,6][is_longscafs1] )
longscafs1
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
longestscaf2 = max(scafdata2[,6])
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
longscafs2 = c(0, scafdata2[,6][is_longscafs2] )
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
# generate 2d data for points by scaffolds
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
MbSr_match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(MbSr_match_freq_table))[is_longscafs1]
sc1_reorder_index
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(MbSr_match_freq_table))[is_longscafs2]
sc2_reorder_index
MbSr_as_xlabs = row.names(MbSr_match_freq_table)[sc1_reorder_index]
MbSr_as_ylabs = colnames(MbSr_match_freq_table)[sc2_reorder_index]

reordered_table = MbSr_match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g1
nscaf_g2 = dim(match_freq_matrix)[2]
nscaf_g2
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
ntests
MbSr_p_values = calculate_ftest_pvalues(match_freq_matrix)
MbSr_p_value_adj = MbSr_p_values * ntests
MbSr_p_value_log = floor(-log10(MbSr_p_value_adj))
hist(MbSr_p_value_log, breaks=20)
MbSr_p_value_log[MbSr_p_value_log<1] = 1
MbSr_p_value_log[MbSr_p_value_log>150] = 150
# final matrix
MbSr_p_value_mat = matrix( data=MbSr_p_value_log, nrow=nscaf_g1, byrow=TRUE )
# write csv
raw_p_value_mat = matrix( data=MbSr_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = MbSr_as_ylabs
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates/monosiga_vs_salpingoeca_ftest_pvalue.csv", row.names=MbSr_as_xlabs )

##
## Randomized Monosiga vs Salpingoeca
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/choanoflagellates/monbr1_vs_srosetta_scaffold2d_points_randomized.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0009)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
# generate 2d data for points by scaffolds
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
sc1_reorder_index
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
sc2_reorder_index
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
MbSr_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
range(MbSr_g_random_p_values)
MbSr_g_random_p_value_adj = MbSr_g_random_p_values * ntests
MbSr_g_random_p_value_log = floor(-log10(MbSr_g_random_p_value_adj))
hist(MbSr_g_random_p_value_log, breaks=20)
MbSr_g_random_p_value_log[MbSr_g_random_p_value_log<1] = 1
MbSr_g_random_p_value_log[MbSr_g_random_p_value_log>150] = 150
# final matrix
MbSr_g_random_p_value_mat = matrix( data=MbSr_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE )
range(MbSr_g_random_p_value_log)
# write csv
raw_p_value_mat = matrix( data=MbSr_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = MbSr_as_ylabs
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates/monosiga_vs_salpingoeca_ftest_pvalue_g-random.csv", row.names=MbSr_as_xlabs )

##
##
##
##
##
## Ephydatia vs Monosiga
##

all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Monosiga_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.009)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
EmMb_match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(EmMb_match_freq_table))[is_longscafs1]
sc1_reorder_index
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(EmMb_match_freq_table))[is_longscafs2]
sc2_reorder_index
Mb_colnames = colnames(EmMb_match_freq_table)[sc2_reorder_index]
reordered_table = EmMb_match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmMb_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmMb_p_value_adj = EmMb_p_values * ntests
EmMb_p_value_log = floor(-log10(EmMb_p_value_adj))
range(EmMb_p_value_log)
EmMb_p_value_log[EmMb_p_value_log<1] = 1
EmMb_p_value_log[EmMb_p_value_log>100] = 100

hist(-log10(EmMb_p_value_adj),breaks=30)
EmMb_p_value_mat = t(matrix( data=EmMb_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmMb_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Mb_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates/ephydatia_vs_monosiga_ftest_pvalue.csv", row.names=row.names(EmMb_match_freq_table)[sc1_reorder_index] )



##
## Randomized Ephydatia vs Monosiga
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Monosiga_scaffold2D_random.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.009)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmMb_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmMb_g_random_p_value_adj = EmMb_g_random_p_values * ntests
EmMb_g_random_p_value_log = floor(-log10(EmMb_g_random_p_value_adj))
range(EmMb_g_random_p_value_log)
EmMb_g_random_p_value_log[EmMb_g_random_p_value_log<1] = 1
EmMb_g_random_p_value_log[EmMb_g_random_p_value_log>100] = 100
# final matrix
hist(-log10(EmMb_g_random_p_value_adj),breaks=30)
EmMb_g_random_p_value_mat = t(matrix( data=EmMb_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
#plot(1:100,1:100,cex=3,pch=18,col=colorscheme)
# write csv
raw_p_value_mat = matrix( data=EmMb_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Mb_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates/ephydatia_vs_monosiga_ftest_pvalue_g-random.csv", row.names=row.names(EmMb_match_freq_table)[sc1_reorder_index] )
# count of NBcS, Number of Bonferroni corrected Scaffolds
EmMb_p_values[(EmMb_p_values / EmMb_g_random_p_values) < (0.01/ntests)]

##
##
## Ephydatia vs Salpingoeca
##
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Srosetta_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.009)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
EmSr_match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(EmSr_match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(EmSr_match_freq_table))[is_longscafs2]
Sr_colnames = colnames(EmSr_match_freq_table)[sc2_reorder_index]
reordered_table = EmSr_match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmSr_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmSr_p_value_adj = EmSr_p_values * ntests
EmSr_p_value_log = floor(-log10(EmSr_p_value_adj))
range(EmSr_p_value_log)
EmSr_p_value_log[EmSr_p_value_log<1] = 1
EmSr_p_value_log[EmSr_p_value_log>100] = 100
hist(-log10(EmSr_p_value_adj),breaks=30)
EmSr_p_value_mat = t(matrix( data=EmSr_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmSr_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Sr_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates/ephydatia_vs_salpingoeca_ftest_pvalue.csv", row.names=row.names(EmSr_match_freq_table)[sc1_reorder_index] )


## Randomized Ephydatia vs Salpingoeca
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Srosetta_scaffold2D_random.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.009)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmSr_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmSr_g_random_p_value_adj = EmSr_g_random_p_values * ntests
EmSr_g_random_p_value_log = floor(-log10(EmSr_g_random_p_value_adj))
range(EmSr_g_random_p_value_log)
EmSr_g_random_p_value_log[EmSr_g_random_p_value_log<1] = 1
EmSr_g_random_p_value_log[EmSr_g_random_p_value_log>100] = 100
hist(-log10(EmSr_g_random_p_value_adj),breaks=30)
EmSr_g_random_p_value_mat = t(matrix( data=EmSr_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmSr_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Sr_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates/ephydatia_vs_salpingoeca_ftest_pvalue_g-random.csv", row.names=row.names(EmSr_match_freq_table)[sc1_reorder_index] )
# Nb
EmSr_p_values[EmSr_p_values < (min(EmSr_g_random_p_values)/ntests)]
# NBcS
EmSr_p_values[(EmSr_p_values / EmSr_g_random_p_values) < (0.01/ntests)]


# generate 6 panel final plot for choanoflagellates
pdf(file="~/genomes/ephydatia_muelleri/synteny/choanoflagellates_ftest_pvalue_squares.pdf", paper="a4", width=8, height=11)
layout(mat=matrix(c(1,2,3,4,5,6), nrow=3, byrow=TRUE),widths=c(1,1,1,1,1,1))
par(mar=c(4,6,3,1))
colorscheme = colorRampPalette(c("#fdf7fc","#c266a4","#4d004b"))(150)
image(z=MbSr_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,150), main="Fisher's exact test P values\n M.brevicollis vs. S.rosetta")
mtext( MbSr_as_xlabs, side=1,at=seq(0,1,1/(length(MbSr_as_xlabs)-1)), las=2, cex=0.5)
mtext( MbSr_as_ylabs,side=2,at=seq(0,1,1/(length(MbSr_as_ylabs)-1)), las=1, cex=0.5)
mtext( "A", side=3, at=c(-0.2), line=1, cex=2)
image(z=MbSr_g_random_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,150), main="Globally randomized Fisher's exact test P values\n M.brevicollis vs. S.rosetta")
mtext( MbSr_as_xlabs, side=1,at=seq(0,1,1/(length(MbSr_as_xlabs)-1)), las=2, cex=0.5)
mtext( MbSr_as_ylabs,side=2,at=seq(0,1,1/(length(MbSr_as_ylabs)-1)), las=1, cex=0.5)
mtext( "B", side=3, at=c(-0.2), line=1, cex=2)
rect(seq(0.600, 0.9725, 0.0025),rep(0.9,length(colorscheme)), seq(0.6025, 0.975, 0.0025) ,rep(0.97,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.6,0.85, "p=0.1", cex=1.2)
text(1,0.85, "<1e-150" , cex=1, pos=2)
# white to green to purple
colorscheme = colorRampPalette(c("#f7fdfc","#66c2a4","#4d004b"))(100)
#plot(1:100,1:100,cex=3,pch=18,col=colorscheme)
image(z=EmMb_p_value_mat, col=colorscheme, zlim=c(1,100), axes=FALSE, main="Fisher's exact test P values\n E.muelleri vs M.brevicollis")
mtext( row.names(EmMb_match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Mb_colnames,side=1,at=seq(0,1,1/(length(Mb_colnames)-1)), las=2, cex=0.4)
mtext( "C", side=3, at=c(-0.2), line=1, cex=2)
image(z=EmMb_g_random_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Globally randomized Fisher's exact test P values\n E.muelleri vs M.brevicollis")
mtext( row.names(EmMb_match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Mb_colnames,side=1,at=seq(0,1,1/(length(Mb_colnames)-1)), las=2, cex=0.4)
mtext( "D", side=3, at=c(-0.2), line=1, cex=2)
rect(seq(0.600, 0.897, 0.003),rep(0.9,length(colorscheme)), seq(0.603, 0.9, 0.003) ,rep(0.97,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.6,0.85, "p=0.1", cex=1.2)
text(1,0.85, "<1e-100" , cex=1, pos=2)
image(z=EmSr_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Fisher's exact test P values\n E.muelleri vs S.rosetta")
mtext( row.names(EmSr_match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Sr_colnames,side=1,at=seq(0,1,1/(length(Sr_colnames)-1)), las=2, cex=0.5)
mtext( "E", side=3, at=c(-0.2), line=1, cex=2)
image(z=EmSr_g_random_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Globally randomized Fisher's exact test P values\n E.muelleri vs S.rosetta")
mtext( row.names(EmSr_match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Sr_colnames,side=1,at=seq(0,1,1/(length(Sr_colnames)-1)), las=2, cex=0.5)
mtext( "F", side=3, at=c(-0.2), line=1, cex=2)
rect(seq(0.600, 0.897, 0.003),rep(0.9,length(colorscheme)), seq(0.603, 0.9, 0.003) ,rep(0.97,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.6,0.85, "p=0.1", cex=1.2)
text(1,0.85, "<1e-100" , cex=1, pos=2)
dev.off()


##
##
##
##
##
##
## Ephydatia vs Trichoplax
##

all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Triad1_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.005)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
Ta_colnames = colnames(match_freq_table)[sc2_reorder_index]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmTa_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmTa_p_value_adj = EmTa_p_values * ntests
EmTa_p_value_log = floor(-log10(EmTa_p_value_adj)/2)
range(EmTa_p_value_log)
EmTa_p_value_log[EmTa_p_value_log<1] = 1
EmTa_p_value_log[EmTa_p_value_log>100] = 100
hist(EmTa_p_value_log,breaks=30)
EmTa_p_value_mat = t(matrix( data=EmTa_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmTa_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Ta_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/metazoa/ephydatia_vs_trichoplax_ftest_pvalue.csv", row.names=row.names(match_freq_table)[sc1_reorder_index] )


## randomized Ephydatia vs Trichoplax
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Triad1_scaffold2D_random.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.005)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
match_total = sum(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmTa_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmTa_g_random_p_value_adj = EmTa_g_random_p_values * ntests
EmTa_g_random_p_value_log = floor(-log10(EmTa_g_random_p_value_adj)/2)
range(EmTa_g_random_p_value_log)
EmTa_g_random_p_value_log[EmTa_g_random_p_value_log<1] = 1
EmTa_g_random_p_value_log[EmTa_g_random_p_value_log>100] = 100
hist(EmTa_g_random_p_value_log,breaks=30)
EmTa_g_random_p_value_mat = t(matrix( data=EmTa_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmTa_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Ta_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/metazoa/ephydatia_vs_trichoplax_ftest_pvalue_g-random.csv", row.names=row.names(match_freq_table)[sc1_reorder_index] )
# Nb
EmTa_p_values[EmTa_p_values < (min(EmTa_g_random_p_values)/ntests)]
# NBcS
EmTa_p_values[(EmTa_p_values / EmTa_g_random_p_values) < (0.01/ntests)]


##
##
## Ephydatia vs Nematostella
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Nve2_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.004)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
Nv_colnames = colnames(match_freq_table)[sc2_reorder_index]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
ntests = nscaf_g1 * nscaf_g2
EmNv_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmNv_p_value_adj = EmNv_p_values * ntests
EmNv_p_value_log = floor(-log10(EmNv_p_value_adj))
range(EmNv_p_value_log)
EmNv_p_value_log[EmNv_p_value_log<1] = 1
EmNv_p_value_log[EmNv_p_value_log>100] = 100
hist(EmNv_p_value_log,breaks=30)
EmNv_p_value_mat = t(matrix( data=EmNv_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmNv_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Nv_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/metazoa/ephydatia_vs_nematostella_ftest_pvalue.csv", row.names=row.names(match_freq_table)[sc1_reorder_index] )

##
##
## randomized Ephydatia vs Nematostella
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Nve2_scaffold2D_random.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.004)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
sc2_reorder_index
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
ntests = nscaf_g1 * nscaf_g2
EmNv_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
EmNv_g_random_p_value_adj = EmNv_g_random_p_values * ntests
EmNv_g_random_p_value_log = floor(-log10(EmNv_g_random_p_value_adj))
range(EmNv_g_random_p_value_log)
EmNv_g_random_p_value_log[EmNv_g_random_p_value_log<1] = 1
EmNv_g_random_p_value_log[EmNv_g_random_p_value_log>100] = 100
hist(EmNv_g_random_p_value_log,breaks=30)
EmNv_g_random_p_value_mat = t(matrix( data=EmNv_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmNv_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Nv_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/metazoa/ephydatia_vs_nematostella_ftest_pvalue_g-random.csv", row.names=row.names(match_freq_table)[sc1_reorder_index] )
# Nb
EmNv_p_values[EmNv_p_values < (min(EmNv_g_random_p_values)/ntests)]
# NBcS
EmNv_p_values[(EmNv_p_values / EmNv_g_random_p_values) < (0.01/ntests)]


##
## Ephydatia vs Branchiostoma
##
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2-AUG_scaffold2D.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
#is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0035)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
Bf_colnames = colnames(match_freq_table)[sc2_reorder_index]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
EmBf_p_values = calculate_ftest_pvalues(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmBf_p_value_adj = EmBf_p_values * ntests
EmBf_p_value_log = floor(-log10(EmBf_p_value_adj))
range(EmBf_p_value_log)
EmBf_p_value_log[EmBf_p_value_log<1] = 1
EmBf_p_value_log[EmBf_p_value_log>150] = 150
hist(-log10(EmBf_p_value_adj),breaks=30)
EmBf_p_value_mat = t(matrix( data=EmBf_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmBf_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Bf_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/metazoa/ephydatia_vs_branchiostoma_ftest_pvalue.csv", row.names=row.names(match_freq_table)[sc1_reorder_index] )


##
## Randomized Ephydatia vs Branchiostoma
##
all2Ddata = read.table("~/genomes/ephydatia_muelleri/synteny/augustus_sysnames_prots_vs_Brafl2-AUG_random_scaffold2D_test.tab", sep="\t", stringsAsFactors=FALSE)
categories = all2Ddata[,1]
is_scaf1 = which(categories=="s1")
scafdata1 = all2Ddata[is_scaf1,]
#is_longscafs1 = which(as.numeric(scafdata1[,5]) > 0.0009)
is_longscafs1 = 1:24
is_scaf2 = which(categories=="s2")
scafdata2 = all2Ddata[is_scaf2,]
scafdata2
is_longscafs2 =  which(as.numeric(scafdata2[,5]) > 0.0035)
is_points = which(categories=="g")
pointsdata = all2Ddata[is_points,]
scaffold_data = data.frame( sc1 = pointsdata[,3], sc2 = pointsdata[,5])
match_freq_table = table(scaffold_data)
scaf1_names = scafdata1[,2]
sc1_reorder_index = match(scaf1_names,row.names(match_freq_table))[is_longscafs1]
scaf2_names = scafdata2[,2]
sc2_reorder_index = match(scaf2_names,colnames(match_freq_table))[is_longscafs2]
reordered_table = match_freq_table[sc1_reorder_index,sc2_reorder_index]
match_freq_matrix = as.matrix(reordered_table)
nscaf_g1 = dim(match_freq_matrix)[1]
nscaf_g2 = dim(match_freq_matrix)[2]
EmBf_g_random_p_values = calculate_ftest_pvalues(match_freq_matrix)
ntests = nscaf_g1 * nscaf_g2
EmBf_g_random_p_value_adj = EmBf_g_random_p_values * ntests
EmBf_g_random_p_value_log = floor(-log10(EmBf_g_random_p_value_adj))
range(EmBf_g_random_p_value_log)
EmBf_g_random_p_value_log[EmBf_g_random_p_value_log<1] = 1
EmBf_g_random_p_value_log[EmBf_g_random_p_value_log>150] = 150
hist(-log10(EmBf_g_random_p_value_adj),breaks=30)
EmBf_g_random_p_value_mat = t(matrix( data=EmBf_g_random_p_value_log, nrow=nscaf_g1, byrow=TRUE ))
# write csv
raw_p_value_mat = matrix( data=EmBf_g_random_p_values, nrow=nscaf_g1, byrow=TRUE )
colnames(raw_p_value_mat) = Bf_colnames
write.csv(raw_p_value_mat, file="~/genomes/ephydatia_muelleri/synteny/metazoa/ephydatia_vs_branchiostoma_ftest_pvalue_g-random.csv", row.names=row.names(match_freq_table)[sc1_reorder_index] )
# Nb
EmBf_p_values[EmBf_p_values < (min(EmBf_g_random_p_values)/ntests)]
# NBcS
EmBf_p_values[(EmBf_p_values / EmBf_g_random_p_values) < (0.01/ntests)]


# generate 6 panel final plot for animals
pdf(file="~/genomes/ephydatia_muelleri/synteny/ephydatia_vs_animals_ftest_pvalue_squares.pdf", paper="a4", width=8, height=11)
layout(mat=matrix(c(1,2,3,4,5,6), nrow=3, byrow=TRUE),widths=c(1,1,1,1,1,1))
par(mar=c(4,6,3,1))
colorscheme = colorRampPalette(c("#f7fdfc","#66c2a4","#4d004b"))(100)
#plot(1:100,1:100,cex=3,pch=18,col=colorscheme)
image(z=EmTa_p_value_mat, col=colorscheme, zlim=c(1,100), axes=FALSE, main="Fisher's exact test P values\n E.muelleri vs T.adhaerens")
mtext( row.names(match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Ta_colnames,side=1,at=seq(0,1,1/(length(Ta_colnames)-1)), las=2, cex=0.5)
mtext( "A", side=3, at=c(-0.2), line=1, cex=2)
image(z=EmTa_g_random_p_value_mat, col=colorscheme, axes=FALSE, zlim=c(1,100), main="Globally randomized Fisher's exact test P values\n E.muelleri vs T.adhaerens")
mtext( row.names(match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Ta_colnames,side=1,at=seq(0,1,1/(length(Ta_colnames)-1)), las=2, cex=0.5)
mtext( "B", side=3, at=c(-0.2), line=1, cex=2)
rect(seq(0.600, 0.897, 0.003),rep(0.9,length(colorscheme)), seq(0.603, 0.9, 0.003) ,rep(0.97,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.6,0.85, "p=0.1", cex=1.2)
text(1,0.85, "<1e-200" , cex=1, pos=2)
image(z=EmNv_p_value_mat, col=colorscheme, zlim=c(1,100), axes=FALSE, main="Fisher's exact test P values\n E.muelleri vs N.vectensis")
mtext( row.names(match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Nv_colnames,side=1,at=seq(0,1,1/(length(Nv_colnames)-1)), las=2, cex=0.5)
mtext( "C", side=3, at=c(-0.2), line=1, cex=2)
image(z=EmNv_g_random_p_value_mat, col=colorscheme, zlim=c(1,100), axes=FALSE, main="Globally randomized Fisher's exact test P values\n E.muelleri vs N.vectensis")
mtext( row.names(match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Nv_colnames,side=1,at=seq(0,1,1/(length(Nv_colnames)-1)), las=2, cex=0.5)
mtext( "D", side=3, at=c(-0.2), line=1, cex=2)
rect(seq(0.600, 0.897, 0.003),rep(0.9,length(colorscheme)), seq(0.603, 0.9, 0.003) ,rep(0.97,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.6,0.85, "p=0.1", cex=1.2)
text(1,0.85, "<1e-100" , cex=1, pos=2)
colorscheme = colorRampPalette(c("#f7fdfc","#66c2a4","#4d004b"))(150)
image(z=EmBf_p_value_mat, col=colorscheme, zlim=c(1,150), axes=FALSE, main="Fisher's exact test P values\n E.muelleri vs B.floridae")
mtext( row.names(match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Bf_colnames,side=1,at=seq(0,1,1/(length(Bf_colnames)-1)), las=2, cex=0.45)
mtext( "E", side=3, at=c(-0.2), line=1, cex=2)
image(z=EmBf_g_random_p_value_mat, col=colorscheme, zlim=c(1,150), axes=FALSE, main="Globally randomized Fisher's exact test P values\n E.muelleri vs B.floridae")
mtext( row.names(match_freq_table)[sc1_reorder_index],side=2,at=seq(0,1,1/(nscaf_g1-1)), las=1, cex=0.6)
mtext( Bf_colnames,side=1,at=seq(0,1,1/(length(Bf_colnames)-1)), las=2, cex=0.45)
mtext( "F", side=3, at=c(-0.2), line=1, cex=2)
rect(seq(0.600, 0.9725, 0.0025),rep(0.9,length(colorscheme)), seq(0.6025, 0.975, 0.0025) ,rep(0.97,length(colorscheme)),col=colorscheme,border=FALSE)
text(0.6,0.85, "p=0.1", cex=1.2)
text(1,0.85, "<1e-150" , cex=1, pos=2)
dev.off()

#p_oddratios_adj = p_oddratios
#p_oddratios_adj[p_oddratios_adj==Inf] = 0
#p_oddratios_adj[p_oddratios_adj>1000] = 1000
#hist(p_oddratios_adj,breaks=100)
#p_oddratios_adj
#p_oddratios_mat = t(matrix(data=p_oddratios_adj,nrow=nscaf_g1, byrow=TRUE))
#image(z=p_oddratios_mat, col=colorscheme, axes=FALSE, main="Fisher's exact test P values - E.muelleri vs B.floridae")


#